# Contributors

## Current Contributors
-  [Max Frank](https://github.com/mffrank): Current lead developer.

## Other Contributors
-  [Duo Peng](https://github.com/duopeng): Developed the orgininal graph-based analysis of subcellular proteomics data.
-  [Marika Clark](https://github.com/marika-clark): Contributed code for Differential centrifugation and experimental design during Summer Internship 2025
